@@ -1,3 +1,3 @@
 from .database import *
 from .sitemap import *
-from .news_entry import *
\ No newline at end of file
+from .news_entry import scheduler_news
\ No newline at end of file
